[PATCH 7/7] opcservices: Change black-/whitelist to more neutral words

André Hentschel nerv at dawncrow.de
Tue Jun 16 08:35:36 CDT 2020


Signed-off-by: André Hentschel <nerv at dawncrow.de>
---
 dlls/opcservices/deflate.c | 18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

diff --git a/dlls/opcservices/deflate.c b/dlls/opcservices/deflate.c
index 681f187ecda..891bdc985f2 100644
--- a/dlls/opcservices/deflate.c
+++ b/dlls/opcservices/deflate.c
@@ -715,9 +715,9 @@ static void compress_block( deflate_state *s, const ct_data *ltree, const ct_dat
  * Check if the data type is TEXT or BINARY, using the following algorithm:
  * - TEXT if the two conditions below are satisfied:
  *    a) There are no non-portable control characters belonging to the
- *       "black list" (0..6, 14..25, 28..31).
+ *       "block list" (0..6, 14..25, 28..31).
  *    b) There is at least one printable character belonging to the
- *       "white list" (9 {TAB}, 10 {LF}, 13 {CR}, 32..255).
+ *       "allow list" (9 {TAB}, 10 {LF}, 13 {CR}, 32..255).
  * - BINARY otherwise.
  * - The following partially-portable control characters form a
  *   "gray list" that is ignored in this detection algorithm:
@@ -726,19 +726,19 @@ static void compress_block( deflate_state *s, const ct_data *ltree, const ct_dat
  */
 static int detect_data_type( deflate_state *s )
 {
     /* black_mask is the bit mask of black-listed bytes
      * set bits 0..6, 14..25, and 28..31
      * 0xf3ffc07f = binary 11110011111111111100000001111111
      */
-    unsigned long black_mask = 0xf3ffc07fUL;
+    unsigned long block_mask = 0xf3ffc07fUL;
     int n;
 
-    /* Check for non-textual ("black-listed") bytes. */
-    for (n = 0; n <= 31; n++, black_mask >>= 1)
-        if ((black_mask & 1) && (s->dyn_ltree[n].Freq != 0))
+    /* Check for non-textual ("block-listed") bytes. */
+    for (n = 0; n <= 31; n++, block_mask >>= 1)
+        if ((block_mask & 1) && (s->dyn_ltree[n].Freq != 0))
             return Z_BINARY;
 
-    /* Check for textual ("white-listed") bytes. */
+    /* Check for textual ("allow-listed") bytes. */
     if (s->dyn_ltree[9].Freq != 0 || s->dyn_ltree[10].Freq != 0
             || s->dyn_ltree[13].Freq != 0)
         return Z_TEXT;
@@ -746,7 +746,7 @@ static int detect_data_type( deflate_state *s )
         if (s->dyn_ltree[n].Freq != 0)
             return Z_TEXT;
 
     /* There are no "black-listed" or "white-listed" bytes:
      * this stream either is empty or has tolerated ("gray-listed") bytes only.
      */
     return Z_BINARY;
@@ -726,19 +726,19 @@ static void compress_block( deflate_state *s, const ct_data *ltree, const ct_dat
 static int detect_data_type( deflate_state *s )
 {
-    /* black_mask is the bit mask of black-listed bytes
+    /* block_mask is the bit mask of block-listed bytes
      * set bits 0..6, 14..25, and 28..31
      * 0xf3ffc07f = binary 11110011111111111100000001111111
@@ -746,7 +746,7 @@ static int detect_data_type( deflate_state *s )
             return Z_TEXT;
 
-    /* There are no "black-listed" or "white-listed" bytes:
+    /* There are no "block-listed" or "allow-listed" bytes:
      * this stream either is empty or has tolerated ("gray-listed") bytes only.
      */
-- 
2.17.1



More information about the wine-devel mailing list